@@ -34,6 +34,11 @@
 #define HAVE_FLOAT_H 1
 #define HAVE_FNMATCH_H 1
 #define HAVE_FPU_CONTROL_H 1
+#define HAVE_GETMNTENT 1
+/* #undef HAVE_GETMNTENT_IN_SYS_MNTAB */
+/* #undef HAVE_GETMNTINFO */
+/* #undef HAVE_GETMNTINFO64 */
+/* #undef HAVE_GETMNTINFO_TAKES_statvfs */
 #define HAVE_GRP_H 1
 /* #undef HAVE_IA64INTRIN_H */
 /* #undef HAVE_IEEEFP_H */
@@ -163,7 +168,6 @@
 #define HAVE_LRAND48 1
 #define HAVE_LOCALTIME_R 1
 #define HAVE_LSTAT 1
-#define HAVE_MEMALIGN 1
 /* #define HAVE_MLOCK 1 see Bug#54662 */
 #define HAVE_NL_LANGINFO 1
 #define HAVE_MADVISE 1
@@ -179,6 +183,7 @@
 #define HAVE_MLOCKALL 1
 #define HAVE_MMAP 1
 #define HAVE_MMAP64 1
+#define HAVE_MPROTECT 1
 #define HAVE_PERROR 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_FALLOCATE 1
@@ -209,6 +214,7 @@
 #define HAVE_SELECT 1
 #define HAVE_SETENV 1
 #define HAVE_SETLOCALE 1
+#define HAVE_SETMNTENT 1
 #define HAVE_SETUPTERM 1
 #define HAVE_SIGSET 1
 #define HAVE_SIGACTION 1
@@ -216,7 +222,6 @@
 #define HAVE_SIGWAIT 1
 #define HAVE_SIGWAITINFO 1
 #define HAVE_SLEEP 1
-#define HAVE_SNPRINTF 1
 #define HAVE_STPCPY 1
 #define HAVE_STRERROR 1
 #define HAVE_STRCOLL 1
@@ -251,9 +256,6 @@
 #define STRUCT_TIMESPEC_HAS_TV_SEC 1
 #define STRUCT_TIMESPEC_HAS_TV_NSEC 1
 
-#define USE_MB 1
-#define USE_MB_IDENT 1
-
 /* this means that valgrind headers and macros are available */
 /* #undef HAVE_VALGRIND_MEMCHECK_H */
 
@@ -449,8 +451,8 @@
 #define MYSQL_DEFAULT_CHARSET_NAME "utf8mb4"
 #define MYSQL_DEFAULT_COLLATION_NAME "utf8mb4_unicode_ci"
 
-#define USE_MB 1
-#define USE_MB_IDENT 1
+#define USE_MB
+#define USE_MB_IDENT
 
 /* This should mean case insensitive file system */
 /* #undef FN_NO_CASE_SENSE */
@@ -527,18 +529,18 @@
 
 /* #undef SO_EXT */
 
-#define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 5
+#define MYSQL_VERSION_MAJOR 11
+#define MYSQL_VERSION_MINOR 1
+#define MYSQL_VERSION_PATCH 2
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.6.5"
+#define PACKAGE_STRING "MySQL Server 11.1.2"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.6.5"
-#define VERSION "10.6.5"
+#define PACKAGE_VERSION "11.1.2"
+#define VERSION "11.1.2"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
@@ -560,3 +562,5 @@
 #endif  // !defined(__STDC_FORMAT_MACROS)
 
 #endif
+
+#define HAVE_VFORK 1
